@@ -429,7 +429,7 @@ do_transfer_command (FtpConnection *conn, gchar *command, GnomeVFSContext *conte
 	if (conn->offset) {
 		gchar *tmpstring;
 
-		tmpstring = g_strdup_printf ("REST %Lu", conn->offset);
+		tmpstring = g_strdup_printf ("REST %"GNOME_VFS_OFFSET_FORMAT_STR, conn->offset);
 		result = do_basic_command (conn, tmpstring);
 		g_free (tmpstring);
 
@@ -733,6 +733,10 @@ ftp_connection_acquire (GnomeVFSURI *uri, FtpConnection **connection, GnomeVFSCo
 						      conn);
 		g_hash_table_insert (spare_connections, uri, 
 				     possible_connections);
+
+		/* Reset offset */
+		conn->offset = 0;
+
 		/* make sure connection hasn't timed out */
 		result = do_basic_command(conn, "PWD");
 		if (result != GNOME_VFS_OK) {
