@@ -175,25 +175,19 @@ typedef struct
 
 typedef ssize_t (*read_write_fn) (int, void *, size_t);
 
-#ifndef TEMP_FAILURE_RETRY
-#define TEMP_FAILURE_RETRY(expression)				\
-	(__extension__						\
-	 ({ long int __result;					\
-	  	do __result = (long int) (expression);		\
-		while (__result == -1L && errno == EINTR);	\
-		__result; }))
-#endif
-
 static gsize
 atomic_io (read_write_fn f, gint fd, gpointer buffer_in, gsize size) 
 {
 	gsize pos = 0, res;
 	guchar *buffer;
+        long int __result;
 
 	buffer = buffer_in;
 
 	while (pos < size) {
-		res = TEMP_FAILURE_RETRY (f (fd, buffer, size - pos));
+	  	do __result = (long int) (f (fd, buffer, size - pos));
+		while (__result == -1L && errno == EINTR);
+		res = __result;
 
 		if (res < 0)
 			return -1;
@@ -520,13 +514,14 @@ buffer_read_file_info (Buffer *buf, GnomeVFSFileInfo *info)
 			       info->permissions));
 
 		info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_TYPE;
-		if (info->permissions & S_IFREG) info->type = GNOME_VFS_FILE_TYPE_REGULAR;
-		else if (info->permissions & S_IFDIR) info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
-		else if (info->permissions & S_IFIFO) info->type = GNOME_VFS_FILE_TYPE_FIFO;
-		else if (info->permissions & S_IFSOCK) info->type = GNOME_VFS_FILE_TYPE_SOCKET;
-		else if (info->permissions & S_IFCHR) info->type = GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE;
-		else if (info->permissions & S_IFBLK) info->type = GNOME_VFS_FILE_TYPE_BLOCK_DEVICE;
-		else if (info->permissions & S_IFLNK) info->type = GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK;
+		
+		if (S_ISREG (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_REGULAR;		
+		else if (S_ISDIR (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
+		else if (S_ISFIFO (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_FIFO;
+		else if (S_ISSOCK (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_SOCKET;
+		else if (S_ISCHR (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_CHARACTER_DEVICE;
+		else if (S_ISBLK (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_BLOCK_DEVICE;
+		else if (S_ISLNK (info->permissions)) info->type = GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK;
 		else info->type = GNOME_VFS_FILE_TYPE_UNKNOWN;
 
 		info->valid_fields |= GNOME_VFS_FILE_INFO_FIELDS_FLAGS;
@@ -1178,6 +1173,12 @@ sftp_get_connection (SftpConnection **connection, const GnomeVFSURI *uri)
 	if (user_name == NULL)
 		user_name = g_get_user_name ();
 
+	if (host_name == NULL)
+	{
+		res = GNOME_VFS_ERROR_HOST_NOT_FOUND;
+		goto bail;
+	}
+
 	hash_name = g_strconcat (user_name, "@", host_name, NULL);
 
 	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG,
@@ -1192,7 +1193,11 @@ sftp_get_connection (SftpConnection **connection, const GnomeVFSURI *uri)
 		res = sftp_connect (connection, uri);
 
 		if (res == GNOME_VFS_OK) {
-			g_return_val_if_fail (*connection != NULL, GNOME_VFS_ERROR_INTERNAL);
+			if (*connection == NULL)
+			{
+				res = GNOME_VFS_ERROR_INTERNAL;
+				goto bail;
+			}
 			g_mutex_lock ((*connection)->mutex);
 			(*connection)->hash_name = hash_name;
 			g_hash_table_insert (sftp_connection_table, hash_name, *connection);
@@ -1224,6 +1229,7 @@ sftp_get_connection (SftpConnection **connection, const GnomeVFSURI *uri)
 		res = GNOME_VFS_OK;
 	}
 
+ bail:
 	G_UNLOCK (sftp_connection_table);
 
 	return res;
@@ -1494,7 +1500,7 @@ do_open (GnomeVFSMethod        *method,
 
 	buffer_write_gint32 (&msg, sftp_mode);
 
-	bzero (&info, sizeof (GnomeVFSFileInfo));
+	memset (&info, 0, sizeof (GnomeVFSFileInfo));
 	buffer_write_file_info (&msg, &info, GNOME_VFS_SET_FILE_INFO_NONE);
 
 	buffer_send (&msg, conn->out_fd);
@@ -1565,11 +1571,19 @@ do_create (GnomeVFSMethod        *method,
 	ssh_mode = SSH2_FXF_CREAT;
 	if (mode & GNOME_VFS_OPEN_READ) ssh_mode |= SSH2_FXF_READ;
 	if (mode & GNOME_VFS_OPEN_WRITE) ssh_mode |= SSH2_FXF_WRITE;
-	if (exclusive) ssh_mode |= SSH2_FXF_EXCL;
+	if (exclusive) {
+		ssh_mode |= SSH2_FXF_EXCL;
+	} else {
+		/* It might be ok to unconditionnally add this truncation flag,
+		 * but I'm not 100% sure that SSH2_FXF_EXCL takes precedence
+		 * over SSH2_FXF_TRUNC, so better be safe than sorry ;)
+		 */
+		ssh_mode |= SSH2_FXF_TRUNC;
+	}
 
 	buffer_write_gint32 (&msg, ssh_mode);
 
-	bzero (&info, sizeof (GnomeVFSFileInfo));
+	memset (&info, 0, sizeof (GnomeVFSFileInfo));
 	info.permissions = perm;
 	buffer_write_file_info (&msg, &info, GNOME_VFS_SET_FILE_INFO_PERMISSIONS);
 
@@ -1642,7 +1656,7 @@ do_close (GnomeVFSMethod       *method,
 
 	DEBUG (g_log (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, "%s: Exit", __FUNCTION__));
 
-	return sftp_status_to_vfs_result (status);
+	return status;
 }
 
 static GnomeVFSResult 
@@ -2265,7 +2279,8 @@ do_read_directory (GnomeVFSMethod       *method,
 			while (handle->info_write_ptr + count > handle->info_alloc) {
 				handle->info_alloc *= 2;
 				handle->info = g_renew (GnomeVFSFileInfo, handle->info, handle->info_alloc);
-				bzero (&(handle->info[handle->info_write_ptr]),
+				memset (&(handle->info[handle->info_write_ptr]),
+					0,
 				       sizeof (GnomeVFSFileInfo) *
 				       (handle->info_alloc - handle->info_write_ptr));
 			}
@@ -2345,14 +2360,14 @@ do_make_directory (GnomeVFSMethod  *method,
 	id = sftp_connection_get_id (conn);
 
 	path = gnome_vfs_unescape_string (gnome_vfs_uri_get_path (uri), NULL);
-	bzero (&info, sizeof (GnomeVFSFileInfo));
+	memset (&info, 0, sizeof (GnomeVFSFileInfo));
 	iobuf_send_string_request_with_file_info (conn->out_fd, id, SSH2_FXP_MKDIR,
 						  path, strlen (path), &info,
 						  GNOME_VFS_SET_FILE_INFO_NONE);
 
 	g_free (path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
@@ -2381,7 +2396,7 @@ do_remove_directory (GnomeVFSMethod  *method,
 
 	g_free (path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
@@ -2424,7 +2439,7 @@ do_move (GnomeVFSMethod  *method,
 	g_free (old_path);
 	g_free (new_path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
@@ -2469,7 +2484,7 @@ do_rename (GnomeVFSMethod  *method,
 	g_free (old_path);
 	g_free (new_path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
@@ -2497,7 +2512,7 @@ do_unlink (GnomeVFSMethod  *method,
 
 	g_free (path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
@@ -2567,7 +2582,7 @@ do_set_file_info (GnomeVFSMethod          *method,
 
 		g_free (path);
 
-		res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+		res = iobuf_read_result (conn->in_fd, id);
 
 		sftp_connection_unref (conn);
 		sftp_connection_unlock (conn);
@@ -2617,7 +2632,7 @@ do_create_symlink (GnomeVFSMethod   *method,
 
 	g_free (path);
 
-	res = sftp_status_to_vfs_result (iobuf_read_result (conn->in_fd, id));
+	res = iobuf_read_result (conn->in_fd, id);
 
 	sftp_connection_unref (conn);
 	sftp_connection_unlock (conn);
